Annotations
============

Containers for model configuration and type information.

.. currentmodule:: torch_concepts.annotations

Summary
-------

**Annotation Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   AxisAnnotation
   Annotations


Class Documentation
-------------------

.. autoclass:: AxisAnnotation
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: Annotations
   :members:
   :undoc-members:
   :show-inheritance:
